@@ -88,6 +88,7 @@ fc_flags_append = {
     "gfortran-15": ["-fallow-invalid-boz", "-fallow-argument-mismatch"],
 }
 
+
 fc_flags_strip = {
     "flang-7": ["-g"],
     "flang-new-18": [
@@ -116,6 +117,24 @@ fc_flags_strip = {
     ],
 }
 
+# Empty for now
+ld_flags_append = {
+    }
+
+ld_flags_strip = {
+    "flang-new-18": [
+        "-mbranch-protection=standard",
+    ],
+    "flang-new-19": [
+        "-mbranch-protection=standard",
+    ],
+    "flang-new-20": [
+        "-mbranch-protection=standard",
+    ],
+    "flang-21": [
+        "-mbranch-protection=standard",
+    ],
+}
 
 def get_fc_flavor(fc: str) -> str:
     """Given a compiler name, work out flavor"""
@@ -146,18 +165,48 @@ def get_flibdir(flavor: str) -> str:
 
 
 def get_fc_flags(flavor: str) -> str:
-    # TODO
     fcflags = check_output(["dpkg-buildflags", "--get", "FCFLAGS_FOR_BUILD"]).strip().decode("utf-8")
-    # TODO match % in flags
+    fcflags_list = fcflags.split()
+    # % in flag means wildcard match after that poin
     if flavor in fc_flags_strip:
         for r in fc_flags_strip[flavor]:
-            if r in fcflags:
-                fcflags.remove(r)
+            if "%" in r:
+                 prefix=r[:r.index('%')]
+                 for x in fcflags_list:
+                     if x.startswith(prefix):
+                         fcflags_list.remove(x)
+            else:
+                if r in fcflags_list:
+                    fcflags_list.remove(r)
+    fcflags = " ".join(fcflags_list)
     if flavor in fc_flags_append:
-        fcflags += " ".join(fc_flags_append[flavor])
+        fcflags += " " + " ".join(fc_flags_append[flavor])
     return fcflags
 
 
+def get_ld_flags(flavor: str) -> str:
+    """ Get the LDFLAGS to use if $FC is used as a linker.
+    TODO: dpkg-buildflags presumes GNU linker, breaks when flang used
+    """
+    ldflags = check_output(["dpkg-buildflags", "--get", "LDFLAGS_FOR_BUILD"]).strip().decode("utf-8")
+    ldflags_list = ldflags.split()
+    # % in flag means wildcard match after that poin
+    if flavor in ld_flags_strip:
+        for r in ld_flags_strip[flavor]:
+            if "%" in r:
+                 prefix=r[:r.index('%')]
+                 for x in ldflags_list:
+                     if x.startswith(prefix):
+                         ldflags_list.remove(x)
+            else:
+                if r in ldflags_list:
+                    ldflags_list.remove(r)
+    ldflags = " ".join(ldflags_list)
+    if flavor in ld_flags_append:
+        ldflags += " " + " ".join(ld_flags_append[flavor])
+    return ldflags
+    
+
 def get_flavor(flavor: str) -> str:
     # FC_FLAVOR matches fortran-support.mk loop-over-flavors variable
     # TODO merge get_fc_flavor
